@@ -1,7 +1,7 @@
 """ Constants """
 
 ID_REPLY = "IDTCMV001"
-ID_WAIT_HISTORY = "IDTWAITPC"
+ID_WAIT_HISTORY = "IDTWAITPCR"
 CONTINUE_REQUEST = [0xa5]
 START_REQUEST = [0x5a]
 PACKET_ID_HISTORY = 0xa9
